import { defineComponent, onMounted, reactive } from 'vue';
import styles from './index.module.less';
import { NTabs, NTabPane, NScrollbar } from 'naive-ui';
import ResourceSearchGroup from '../../model/resource-search-group';
import CardType from '@/components/card-type';
import { useElementSize } from '@vueuse/core';
import { useRect } from '@vant/use';

export default defineComponent({
  name: 'resource-main',
  props: {
    selectionHeight: {
      type: String,
      default: '100%'
    }
  },
  setup() {
    const forms = reactive({
      list: [
        {
          id: 1,
          type: 'IMG',
          url: 'https://lanhu-dds-backend.oss-cn-beijing.aliyuncs.com/merge_image/imgs/24a8551d69b245e0aec1c8613bf50d46_mergeImage.png',
          title: '夏日曲演奏',
          isCollect: false, // 是否收藏
          isSelected: false // 是否精选
        },
        {
          id: 2,
          type: 'IMG',
          url: 'https://lanhu-dds-backend.oss-cn-beijing.aliyuncs.com/merge_image/imgs/24a8551d69b245e0aec1c8613bf50d46_mergeImage.png',
          title: '欢乐颂',
          isCollect: true, // 是否收藏
          isSelected: true // 是否精选
        },
        {
          id: 3,
          type: 'IMG',
          url: 'https://lanhu-dds-backend.oss-cn-beijing.aliyuncs.com/merge_image/imgs/24a8551d69b245e0aec1c8613bf50d46_mergeImage.png',
          title: '夏日曲演奏',
          isCollect: false, // 是否收藏
          isSelected: true // 是否精选
        },
        {
          id: 4,
          type: 'IMG',
          url: 'https://lanhu-dds-backend.oss-cn-beijing.aliyuncs.com/merge_image/imgs/24a8551d69b245e0aec1c8613bf50d46_mergeImage.png',
          title: '欢乐颂',
          isCollect: true, // 是否收藏
          isSelected: false // 是否精选
        }
      ],
      height: '100%' as any
    });

    return () => (
      <div class={styles['resource-main']}>
        <NTabs
          animated
          defaultValue="shareResources"
          paneClass={styles.paneTitle}
          paneWrapperClass={styles.paneWrapperContainer}>
          {{
            suffix: () => (
              <div class={styles.iconScreen}>
                <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24">
                  <g fill="none">
                    <path
                      d="M5 6a1 1 0 0 1 1-1h2a1 1 0 0 0 0-2H6a3 3 0 0 0-3 3v2a1 1 0 0 0 2 0V6zm0 12a1 1 0 0 0 1 1h2a1 1 0 1 1 0 2H6a3 3 0 0 1-3-3v-2a1 1 0 1 1 2 0v2zM18 5a1 1 0 0 1 1 1v2a1 1 0 1 0 2 0V6a3 3 0 0 0-3-3h-2a1 1 0 1 0 0 2h2zm1 13a1 1 0 0 1-1 1h-2a1 1 0 1 0 0 2h2a3 3 0 0 0 3-3v-2a1 1 0 1 0-2 0v2z"
                      fill="#198CFE"></path>
                  </g>
                </svg>
              </div>
            ),
            default: () => (
              <>
                <NTabPane name="shareResources" tab="共享资源">
                  <ResourceSearchGroup />
                  <NScrollbar class={styles.listContainer}>
                    <div class={styles.list}>
                      {forms.list.map((item: any) => (
                        <CardType isShowAdd item={item} />
                      ))}
                    </div>
                  </NScrollbar>
                </NTabPane>
                <NTabPane name="myResources" tab="我的资源">
                  <ResourceSearchGroup />
                  <NScrollbar class={styles.listContainer}>
                    <div class={styles.list}>
                      {forms.list.map((item: any) => (
                        <CardType isShowAdd item={item} />
                      ))}
                    </div>
                  </NScrollbar>
                </NTabPane>
                <NTabPane name="myCollect" tab="我的收藏">
                  <ResourceSearchGroup />
                  <NScrollbar class={styles.listContainer}>
                    <div class={styles.list}>
                      {forms.list.map((item: any) => (
                        <CardType isShowAdd item={item} />
                      ))}
                    </div>
                  </NScrollbar>
                </NTabPane>
              </>
            )
          }}
        </NTabs>
      </div>
    );
  }
});
